bridge

package
v1.2.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

AGPL v3 License Copyright (c) 2026 Project Backplane

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

AGPL v3 License Copyright (c) 2026 Project Backplane

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AtomicContainer added in v1.2.0

type AtomicContainer interface {
}

AtomicContainer interface allows us to treat all atomic types generically

type Bridge

type Bridge struct {
	// contains filtered or unexported fields
}

Bridge handles the connection between the app's runtime state and the admin panel.

func New added in v1.2.0

func New() *Bridge

New creates a new Backplane Bridge instance

func (*Bridge) Expose added in v1.2.0

func (b *Bridge) Expose(label string, ptr interface{})

Expose registers an atomic variable to be editable/viewable in the admin panel.

func (*Bridge) GetBindings added in v1.2.0

func (b *Bridge) GetBindings() map[string]interface{}

GetBindings returns a snapshot of the current bindings.

func (*Bridge) GetInfo added in v1.2.0

func (b *Bridge) GetInfo(label string) string

GetInfo returns metadata about the variable (Type as string)

func (*Bridge) SetAuditLogger added in v1.2.0

func (b *Bridge) SetAuditLogger(w io.Writer)

SetAuditLogger configures where audit logs are written

func (*Bridge) SetValue added in v1.2.0

func (b *Bridge) SetValue(label string, newVal interface{}, operator string) error

SetValue sets the value of a bound variable and logs the action.

func (*Bridge) SetValueFromString added in v1.2.5

func (b *Bridge) SetValueFromString(label string, valStr string, operator string) error

SetValueFromString sets the value of a bound variable from a string input.

Jump to