logger

package
v1.2.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

AGPL v3 License Copyright (c) 2026 Project Backplane

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RingLogger

type RingLogger struct {
	// contains filtered or unexported fields
}

RingLogger is a fixed-size circular buffer for logs.

func NewRingLogger

func NewRingLogger(size int) *RingLogger

NewRingLogger creates a new logger with the given size.

func (*RingLogger) Log

func (r *RingLogger) Log(msg string)

Log adds a message to the buffer.

func (*RingLogger) ReadAll

func (r *RingLogger) ReadAll() []string

ReadAll returns all valid logs in chronological order.

Jump to