tui

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: AGPL-3.0 Imports: 14 Imported by: 0

Documentation

Overview

AGPL v3 License Copyright (c) 2026 Project Backplane

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

AGPL v3 License Copyright (c) 2026 Project Backplane

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MakeHandler added in v1.2.0

func MakeHandler(b *bridge.Bridge, l *logger.RingLogger, c *stats.Cache) func(ssh.Session) (tea.Model, []tea.ProgramOption)

MakeHandler creates a bubbletea middleware handler with injected dependencies

Types

type EditorModel

type EditorModel struct {
	Bridge *bridge.Bridge
	// contains filtered or unexported fields
}

Editor Model

func InitialEditor

func InitialEditor(b *bridge.Bridge) EditorModel

func (*EditorModel) Refresh

func (m *EditorModel) Refresh()

func (EditorModel) Update

func (m EditorModel) Update(msg tea.Msg, operator string) (EditorModel, tea.Cmd)

func (EditorModel) View

func (m EditorModel) View() string

type StatsMsg

type StatsMsg stats.Snapshot

Jump to