pkg

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: AGPL-3.0 Imports: 21 Imported by: 0

Documentation

Overview

AGPL v3 License Copyright (c) 2026 Project Backplane

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

AGPL v3 License Copyright (c) 2026 Project Backplane

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

AGPL v3 License Copyright (c) 2026 Project Backplane

Index

Constants

This section is empty.

Variables

var ReloadSignal = syscall.SIGHUP

Functions

This section is empty.

Types

type Backplane added in v1.2.0

type Backplane struct {
	Options Options
	// contains filtered or unexported fields
}

Backplane is the main instance of the admin server

func New added in v1.2.0

func New(opts Options) *Backplane

New creates a new Backplane instance.

func (*Backplane) Expose added in v1.2.0

func (b *Backplane) Expose(label string, ptr interface{})

Expose registers an atomic variable to be editable/viewable in the admin panel. This delegates to the internal bridge.

func (*Backplane) Log added in v1.2.0

func (b *Backplane) Log(format string, args ...interface{})

Log adds a message to the internal ring buffer and external structured log.

func (*Backplane) Start added in v1.2.0

func (b *Backplane) Start() (func(), error)

Start launches the SSH server in a survivor goroutine.

type Options

type Options struct {
	// Port to listen on. Default: 2222
	Port int
	// Host to bind to. Default: "127.0.0.1" (Safety Default)
	Host string
	// Path to host key. Default: ".ssh/term_info_ed25519"
	HostKeyPath string
	// Path to authorized_keys. Default: "~/.ssh/authorized_keys"
	AuthorizedKeysPath string
	// Destination for Audit Logs. Default: os.Stdout
	AuditOutput io.Writer
	// Destination for Structured Logs (JSON). Default: os.Stderr
	LogOutput io.Writer
}

Options defines configuration for the Backplane server.

func DefaultOptions

func DefaultOptions() Options

DefaultOptions returns safe defaults.

Directories

Path Synopsis

Jump to