Documentation
¶
Overview ¶
AGPL v3 License Copyright (c) 2026 Project Backplane
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
AGPL v3 License Copyright (c) 2026 Project Backplane
Index ¶
- type AtomicContainer
- type Bridge
- func (b *Bridge) Expose(label string, ptr interface{})
- func (b *Bridge) GetBindings() map[string]interface{}
- func (b *Bridge) GetInfo(label string) string
- func (b *Bridge) SetAuditLogger(w io.Writer)
- func (b *Bridge) SetValue(label string, newVal interface{}, operator string) error
- func (b *Bridge) SetValueFromString(label string, valStr string, operator string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AtomicContainer ¶ added in v1.2.0
type AtomicContainer interface {
}
AtomicContainer interface allows us to treat all atomic types generically
type Bridge ¶
type Bridge struct {
// contains filtered or unexported fields
}
Bridge handles the connection between the app's runtime state and the admin panel.
func (*Bridge) Expose ¶ added in v1.2.0
Expose registers an atomic variable to be editable/viewable in the admin panel.
func (*Bridge) GetBindings ¶ added in v1.2.0
GetBindings returns a snapshot of the current bindings.
func (*Bridge) GetInfo ¶ added in v1.2.0
GetInfo returns metadata about the variable (Type as string)
func (*Bridge) SetAuditLogger ¶ added in v1.2.0
SetAuditLogger configures where audit logs are written