Documentation
¶
Overview ¶
AGPL v3 License Copyright (c) 2026 Project Backplane
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Expose ¶
func Expose(label string, ptr interface{})
Expose registers a variable to be editable/viewable in the admin panel. label: Display name in the TUI ptr: Pointer to the variable
func GetBindings ¶
func GetBindings() map[string]interface{}
GetBindings returns a snapshot of the current bindings. It returns map[label]value (interface{})
func SetAuditLogger ¶
SetAuditLogger configures where audit logs are written